@@ -1,5 +1,4 @@
 from PasswordCardGenerator import PasswordCard
-import PasswordCardGenerator.Web as Web
 from random import choices, randint
 from os import path
 import argparse
@@ -111,15 +110,10 @@ parser.add_argument("-t", "--txt", action="store_true", help="Saves the Password
 parser.add_argument("-p", "--png", action="store_true", help="Saves the Password Card as a PNG ")
 parser.add_argument("-s", "--seed", action="store", type=str or int, help="Set the seed")
 parser.add_argument("--pwd", action="store_true", help="Gets the Password for [keyword]")
-parser.add_argument("--web", action="store_true", help="Start the Web version")
 
 # getting the args
 args = parser.parse_args()
 
-if args.web:
-    Web.run()
-    exit(0)
-
 # generating keyword if needed
 keyword, generated = '.'.join(args.keyword), False
 if keyword.upper() == "!GENERATE":
@@ -147,7 +141,7 @@ if args.png:
         filename = f"card_{randint(1000, 100000000)}.png"
 
     # saving the card
-    card.save(filename)
+    card.save_png(filename)
     print(f"Saved card as '{filename}'")
 ## save as text if flag is set
 if args.txt:
@@ -161,5 +155,5 @@ if args.txt:
         filename = f"card_{randint(1000, 100000000)}.txt"
 
     # saving the card
-    card.save(filename, txt=True)
+    card.save_text(filename)
     print(f"Saved card as '{filename}'")
